@@ -35,6 +35,8 @@
 #define SORT_FLAGGED	17
 #define SORT_PATH	18
 #define SORT_LABEL	19
+#define SORT_AUX        20  /* $sort_thread_groups delegation to $sort_aux */
+#define SORT_UID        21  /* used internally by the IMAP code */
 
 /* Sort and sort_aux are shorts, and are a composite of a
  * constant sort operation number and a set of compounded
@@ -65,6 +67,7 @@ WHERE short BrowserSort INITVAL (SORT_SUBJECT);
 WHERE short BrowserSortMailboxes INITVAL (SORT_ORDER);
 WHERE short Sort INITVAL (SORT_DATE);
 WHERE short SortAux INITVAL (SORT_DATE); /* auxiliary sorting method */
+WHERE short SortThreadGroups INITVAL (SORT_AUX); /* thread roots sorting method */
 WHERE short SortAlias INITVAL (SORT_ALIAS);
 WHERE short SidebarSortMethod INITVAL (SORT_ORDER);
 
